@@ -38,32 +38,27 @@
 #include "kpLogCategories.h"
 #include <KLocalizedString>
 
-#include <qcheckbox.h>
-#include <qimage.h>
-#include <qlayout.h>
-#include <qpixmap.h>
-
+#include <QCheckBox>
+#include <QVBoxLayout>
 
 kpEffectInvertWidget::kpEffectInvertWidget (bool actOnSelection,
                                             QWidget *parent)
     : kpEffectWidgetBase (actOnSelection, parent)
 {
-    QVBoxLayout *topLevelLay = new QVBoxLayout (this);
-    topLevelLay->setMargin (0);
+    auto *topLevelLay = new QVBoxLayout (this);
+    topLevelLay->setContentsMargins(0, 0, 0, 0);
 
-
-    QWidget *centerWidget = new QWidget (this);
+    auto *centerWidget = new QWidget (this);
     topLevelLay->addWidget (centerWidget, 0/*stretch*/, Qt::AlignCenter);
 
-
-    QVBoxLayout *centerWidgetLay = new QVBoxLayout (centerWidget );
-    centerWidgetLay->setMargin (0);
+    auto *centerWidgetLay = new QVBoxLayout (centerWidget );
+    centerWidgetLay->setContentsMargins(0, 0, 0, 0);
 
     m_redCheckBox = new QCheckBox (i18n ("&Red"), centerWidget);
     m_greenCheckBox = new QCheckBox (i18n ("&Green"), centerWidget);
     m_blueCheckBox = new QCheckBox (i18n ("&Blue"), centerWidget);
 
-    QWidget *spaceWidget = new QWidget (centerWidget);
+    auto *spaceWidget = new QWidget (centerWidget);
     spaceWidget->setFixedSize (1, fontMetrics ().height () / 4);
 
     m_allCheckBox = new QCheckBox (i18n ("&All"), centerWidget);
@@ -86,20 +81,20 @@ kpEffectInvertWidget::kpEffectInvertWidget (bool actOnSelection,
 
 
     m_inSignalHandler = false;
-    connect (m_redCheckBox, SIGNAL (toggled(bool)),
-             this, SLOT (slotRGBCheckBoxToggled()));
-    connect (m_greenCheckBox, SIGNAL (toggled(bool)),
-             this, SLOT (slotRGBCheckBoxToggled()));
-    connect (m_blueCheckBox, SIGNAL (toggled(bool)),
-             this, SLOT (slotRGBCheckBoxToggled()));
+    connect (m_redCheckBox, &QCheckBox::toggled,
+             this, &kpEffectInvertWidget::slotRGBCheckBoxToggled);
 
-    connect (m_allCheckBox, SIGNAL (toggled(bool)),
-             this, SLOT (slotAllCheckBoxToggled()));
+    connect (m_greenCheckBox, &QCheckBox::toggled,
+             this, &kpEffectInvertWidget::slotRGBCheckBoxToggled);
+
+    connect (m_blueCheckBox, &QCheckBox::toggled,
+             this, &kpEffectInvertWidget::slotRGBCheckBoxToggled);
+
+    connect (m_allCheckBox, &QCheckBox::toggled,
+             this, &kpEffectInvertWidget::slotAllCheckBoxToggled);
 }
 
-kpEffectInvertWidget::~kpEffectInvertWidget ()
-{
-}
+kpEffectInvertWidget::~kpEffectInvertWidget () = default;
 
 
 // public
@@ -116,14 +111,17 @@ int kpEffectInvertWidget::channels () const
     int channels = 0;
 
 
-    if (m_redCheckBox->isChecked ())
+    if (m_redCheckBox->isChecked ()) {
         channels |= kpEffectInvert::Red;
+    }
 
-    if (m_greenCheckBox->isChecked ())
+    if (m_greenCheckBox->isChecked ()) {
         channels |= kpEffectInvert::Green;
+    }
 
-    if (m_blueCheckBox->isChecked ())
+    if (m_blueCheckBox->isChecked ()) {
         channels |= kpEffectInvert::Blue;
+    }
 
 
 #if DEBUG_KP_EFFECT_INVERT
@@ -170,8 +168,9 @@ kpEffectCommandBase *kpEffectInvertWidget::createCommand (
 // protected slots
 void kpEffectInvertWidget::slotRGBCheckBoxToggled ()
 {
-    if (m_inSignalHandler)
+    if (m_inSignalHandler) {
         return;
+    }
 
     m_inSignalHandler = true;
 
@@ -189,8 +188,9 @@ void kpEffectInvertWidget::slotRGBCheckBoxToggled ()
 // protected slot
 void kpEffectInvertWidget::slotAllCheckBoxToggled ()
 {
-    if (m_inSignalHandler)
+    if (m_inSignalHandler) {
         return;
+    }
 
     m_inSignalHandler = true;
 
