@@ -39,7 +39,7 @@ Q_OBJECT
 
 public:
     kpToolWidgetOpaqueOrTransparent (QWidget *parent, const QString &name);
-    virtual ~kpToolWidgetOpaqueOrTransparent ();
+    ~kpToolWidgetOpaqueOrTransparent () override;
 
     bool isOpaque () const;
     bool isTransparent () const;
@@ -50,7 +50,7 @@ signals:
     void isOpaqueChanged (bool isOpaque);
 
 protected slots:
-    bool setSelected (int row, int col, bool saveAsDefault) Q_DECL_OVERRIDE;
+    bool setSelected (int row, int col, bool saveAsDefault) override;
 };
 
 
